<?php

use Scriptor\Core\Scriptor;

/**
 * The getSite() method returns an instance of a class that 
 * represents the current website.
 */
$site = Scriptor::getSite();

/**
 * Renders the navigation bar for a given site.
 *
 * @param string $site The website object.
 * @return string The HTML code for the navigation bar.
 */
function renderNavBar($site) : string
{
    $output = '';

    ob_start();
    include '_navbar.php';
    $output .= ob_get_clean();

    return $output;	
}

/**
 * Renders the header of the website.
 *
 * @param object $site The website object
 * @return string The HTML code for the header
 */
function renderHeader($site) : string
{
    $output = '';
    $header = $site->pages()->getPage('template=opw-header');

    if (!$header) return $output;

    ob_start();
    include '_header.php';
    $output .= ob_get_clean();

    return $output;	
}

/**
 * Renders a list of articles on a given site.
 *
 * @param object $site The site object to render articles for
 * @return string The HTML output of the rendered articles
 */
function renderArticle($site) : string
{
    $output = '';
    $articles = $site->pages()->getPages('template=opw-article');

    if (!$articles) return $output;

    $order_image_classes = [' order-lg-2', ' order-lg-1'];
    $order_text_classes = [' order-lg-1', ' order-lg-2'];
    $class_index = 0;

    foreach ($articles as $article) {
        ob_start();
        include '_article.php';
        $output .= ob_get_clean();

        $class_index = ($class_index + 1) % count($order_image_classes);
    }

    return $output;
}

/**
 * Renders the footer section for the given site.
 *
 * @param string $site The website object
 * @return string The HTML code for the footer
 */
function renderFooter($site) : string
{
    $output = '';

    ob_start();
    include '_footer.php';
    $output .= ob_get_clean();

    return $output;	
}